@@ -110,7 +110,7 @@ static int screenshotTypeFromString(const QString& str)
 
 const static QStringList _imageFormats = {"png", "jpg"};
 
-Config* Config::ptrInstance = 0;
+Config* Config::ptrInstance = nullptr;
 
 // constructor
 Config::Config()
@@ -136,7 +136,7 @@ Config* Config::instance()
     return ptrInstance;
 }
 
-void Config::setValue(const QString &key, QVariant val)
+void Config::setValue(const QString &key, const QVariant &val)
 {
     _confData[key] = val;
 }
@@ -151,7 +151,7 @@ void Config::killInstance()
     if (ptrInstance)
     {
         delete ptrInstance;
-        ptrInstance = 0;
+        ptrInstance = nullptr;
     }
 }
 
@@ -230,7 +230,7 @@ QString Config::getSaveDir()
     return value(KEY_SAVEDIR).toString();
 }
 
-void Config::setSaveDir(QString path)
+void Config::setSaveDir(const QString &path)
 {
     setValue(KEY_SAVEDIR, path);
 }
@@ -240,17 +240,17 @@ QString Config::getSaveFileName()
     return value(KEY_SAVENAME).toString();
 }
 
-void Config::setSaveFileName(QString fileName)
+void Config::setSaveFileName(const QString &fileName)
 {
     setValue(KEY_SAVENAME, fileName);
 }
 
 QString Config::getSaveFormat()
 {
-    return value(KEY_SAVEFORMAT).toString();
+    return value(KEY_SAVEFORMAT).toString().toLower();
 }
 
-void Config::setSaveFormat(QString format)
+void Config::setSaveFormat(const QString &format)
 {
     setValue(KEY_SAVEFORMAT, format);
 }
@@ -383,7 +383,7 @@ QString Config::getDateTimeTpl()
     return value(KEY_DATETIME_TPL).toString();
 }
 
-void Config::setDateTimeTpl(QString tpl)
+void Config::setDateTimeTpl(const QString &tpl)
 {
     setValue(KEY_DATETIME_TPL, tpl);
 }
